pub struct StatusLine {
pub mode: String,
pub path: Option<String>,
pub cursor: Position,
pub modified: bool,
pub line_count: u32,
}Fields
mode: Stringpath: Option<String>cursor: Positionmodified: boolline_count: u32Trait Implementations
Sourceimpl Clone for StatusLine
impl Clone for StatusLine
Sourcefn clone(&self) -> StatusLine
fn clone(&self) -> StatusLine
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StatusLine
impl Debug for StatusLine
Sourceimpl Default for StatusLine
impl Default for StatusLine
Sourcefn default() -> StatusLine
fn default() -> StatusLine
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StatusLine
impl<'de> Deserialize<'de> for StatusLine
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StatusLine
impl JsonSchema for StatusLine
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StatusLine
impl RefUnwindSafe for StatusLine
impl Send for StatusLine
impl Sync for StatusLine
impl Unpin for StatusLine
impl UnsafeUnpin for StatusLine
impl UnwindSafe for StatusLine